@@ -21,3 +21,25 @@ test_that("example_textgrid works", {
   tg <- read_textgrid(path)
   expect_equal(nrow(tg), 3)
 })
+
+test_that("encoding support", {
+  example_textgrid(1) |>
+    read_textgrid(encoding = "UTF-8") |>
+    nrow() |>
+    expect_equal(3)
+
+  example_textgrid(1) |>
+    read_textgrid() |>
+    nrow() |>
+    expect_equal(3)
+
+  example_textgrid(2) |>
+    read_textgrid(encoding = "UTF-16") |>
+    nrow() |>
+    expect_equal(3)
+
+  example_textgrid(2) |>
+    read_textgrid() |>
+    nrow() |>
+    expect_equal(3)
+})
